aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/contrib/losses/python/losses/loss_ops.py
diff options
context:
space:
mode:
Diffstat (limited to 'tensorflow/contrib/losses/python/losses/loss_ops.py')
-rw-r--r--tensorflow/contrib/losses/python/losses/loss_ops.py13
1 files changed, 7 insertions, 6 deletions
diff --git a/tensorflow/contrib/losses/python/losses/loss_ops.py b/tensorflow/contrib/losses/python/losses/loss_ops.py
index f6d3601c7d..1d2477b8b7 100644
--- a/tensorflow/contrib/losses/python/losses/loss_ops.py
+++ b/tensorflow/contrib/losses/python/losses/loss_ops.py
@@ -301,7 +301,7 @@ def absolute_difference(predictions, labels=None, weights=1.0, scope=None):
@deprecated("2016-12-30",
"Use tf.losses.sigmoid_cross_entropy instead. Note that the order "
- "of the predictions and labels arguments was changed.")
+ "of the predictions and labels arguments has been changed.")
def sigmoid_cross_entropy(
logits, multi_class_labels, weights=1.0, label_smoothing=0, scope=None):
"""Creates a cross-entropy loss using tf.nn.sigmoid_cross_entropy_with_logits.
@@ -436,7 +436,7 @@ def sparse_softmax_cross_entropy(logits, labels, weights=1.0, scope=None):
@deprecated("2016-12-30",
"Use tf.losses.log_loss instead. Note that the order of the "
- "predictions and labels arguments was changed.")
+ "predictions and labels arguments has been changed.")
def log_loss(predictions, labels=None, weights=1.0, epsilon=1e-7, scope=None):
"""Adds a Log Loss term to the training procedure.
@@ -477,7 +477,8 @@ def log_loss(predictions, labels=None, weights=1.0, epsilon=1e-7, scope=None):
@deprecated("2016-12-30",
"Use tf.losses.hinge_loss instead. Note that the order of the "
- "predictions and labels arguments were changed.")
+ "logits and labels arguments has been changed, and to stay "
+ "unweighted, reduction=Reduction.NONE")
def hinge_loss(logits, labels=None, scope=None):
"""Method that returns the loss tensor for hinge loss.
@@ -488,8 +489,8 @@ def hinge_loss(logits, labels=None, scope=None):
scope: The scope for the operations performed in computing the loss.
Returns:
- A `Tensor` of same shape as `logits` and `labels` representing the loss
- values across the batch.
+ An unweighted `Tensor` of same shape as `logits` and `labels` representing the
+ loss values across the batch.
Raises:
ValueError: If the shapes of `logits` and `labels` don't match.
@@ -541,7 +542,7 @@ def mean_squared_error(predictions, labels=None, weights=1.0, scope=None):
@deprecated("2016-12-30",
"Use tf.losses.mean_pairwise_squared_error instead. Note that the "
- "order of the predictions and labels arguments was changed.")
+ "order of the predictions and labels arguments has been changed.")
def mean_pairwise_squared_error(
predictions, labels=None, weights=1.0, scope=None):
"""Adds a pairwise-errors-squared loss to the training procedure.